@@ -117,7 +117,13 @@ class Configuration : public sigc::trackable
         static bool s_random_turns;
         static bool s_quick_start;
         static bool s_cusp_of_war;
+        static bool s_decorated;
+        static bool s_remember_recent_games;
 
+	static GameParameters::NeutralCities neutralCitiesFromString(const std::string str);
+	static std::string neutralCitiesToString(const GameParameters::NeutralCities neutrals);
+	static GameParameters::RazingCities razingCitiesFromString(const std::string str);
+	static std::string razingCitiesToString(const GameParameters::RazingCities razing);
 	//autos
     private:
         /** \brief The callback for the XML_Helper
