@@ -21,6 +21,7 @@
 //  02110-1301, USA.
 
 #include <sstream>
+#include <sigc++/functors/mem_fun.h>
 
 #include "CreateScenario.h"
 #include "GameScenario.h"
@@ -104,6 +105,12 @@ void CreateScenario::setMaptype(MapType type)
         delete d_generator;
 
     d_generator = new MapGenerator();
+    d_generator->progress.connect (sigc::mem_fun(*this, &CreateScenario::on_progress));
+}
+    
+void CreateScenario::on_progress(double percent, std::string description)
+{
+  progress.emit();
 }
 
 void CreateScenario::setPercentages(int pgrass, int pwater, int pforest,
@@ -197,7 +204,7 @@ void CreateScenario::setWidth(int width)
 
     if (width < 0)
     {
-        std::cerr <<_("CreateScenario:: wrong width given\n");
+        std::cerr << "CreateScenario:: wrong width given\n";
         return;
     }
 
@@ -212,7 +219,7 @@ void CreateScenario::setHeight(int height)
 
     if (height < 0)
     {
-        std::cerr <<_("CreateScenario:: wrong height given\n");
+        std::cerr << "CreateScenario:: wrong height given\n";
         return;
     }
 
@@ -532,11 +539,12 @@ bool CreateScenario::setupCities(bool cities_can_produce_allies,
     return true;
 }
 
+
 bool CreateScenario::setupRoads()
 {
   Roadlist* rl = Roadlist::getInstance();
   for (Roadlist::iterator it = rl->begin(); it != rl->end(); it++)
-    (*it)->setType(Roadlist::getInstance()->calculateType((*it)->getPos()));
+    (*it)->setType(calculateRoadType((*it)->getPos()));
   return true;
 }
 
@@ -848,3 +856,71 @@ void CreateScenario::getBaseGold (int difficulty, int *base_gold)
   else
     *base_gold = 700;
 }
+
+int CreateScenario::calculateRoadType (Vector<int> t)
+{
+    Roadlist *rl = Roadlist::getInstance();
+    Bridgelist *bl = Bridgelist::getInstance();
+
+    // examine neighbour tiles to discover whether there's a road or
+    // bridge on them
+    bool u = false; //up
+    bool b = false; //bottom
+    bool l = false; //left
+    bool r = false; //right
+
+    if (t.y > 0)
+      u = rl->getObjectAt(t + Vector<int>(0, -1));
+    if (t.y < GameMap::getHeight() - 1)
+      b = rl->getObjectAt(t + Vector<int>(0, 1));
+    if (t.x > 0)
+      l = rl->getObjectAt(t + Vector<int>(-1, 0));
+    if (t.x < GameMap::getWidth() - 1)
+      r = rl->getObjectAt(t + Vector<int>(1, 0));
+
+    if (!u && t.y > 0)
+      u = bl->getObjectAt(t + Vector<int>(0, -1));
+    if (!b && t.y < GameMap::getHeight() - 1)
+      b = bl->getObjectAt(t + Vector<int>(0, 1));
+    if (!l && t.x > 0)
+      l = bl->getObjectAt(t + Vector<int>(-1, 0));
+    if (!r && t.x < GameMap::getWidth() - 1)
+      r = bl->getObjectAt(t + Vector<int>(1, 0));
+
+    // then translate this to the type
+    int type = 2; 
+    //show road type 2 when no other road tiles are around
+    if (!u && !b && !l && !r)
+	type = 2;
+    else if (u && b && l && r)
+	type = 2;
+    else if (!u && b && l && r)
+	type = 9;
+    else if (u && !b && l && r)
+	type = 8;
+    else if (u && b && !l && r)
+	type = 7;
+    else if (u && b && l && !r)
+	type = 10;
+    else if (u && b && !l && !r)
+	type = 1;
+    else if (!u && !b && l && r)
+	type = 0;
+    else if (u && !b && l && !r)
+	type = 3;
+    else if (u && !b && !l && r)
+	type = 4;
+    else if (!u && b && l && !r)
+	type = 6;
+    else if (!u && b && !l && r)
+	type = 5;
+    else if (u && !b && !l && !r)
+	type = Road::CONNECTS_NORTH;
+    else if (!u && b && !l && !r)
+	type = Road::CONNECTS_SOUTH;
+    else if (!u && !b && l && !r)
+	type = Road::CONNECTS_WEST;
+    else if (!u && !b && !l && r)
+	type = Road::CONNECTS_EAST;
+    return type;
+}
