@@ -25,8 +25,10 @@
 #include <vector>
 #include <list>
 #include <SDL.h>
+#include <sigc++/signal.h>
 #include "CreateScenarioRandomize.h"
 #include "game-parameters.h"
+#include "vector.h"
 
 class MapGenerator;
 class GameScenario;
@@ -170,6 +172,11 @@ class CreateScenario : public CreateScenarioRandomize
         bool dump(std::string filename) const;
 
 	MapGenerator *getGenerator() const {return d_generator;};
+	static int calculateRoadType (Vector<int> t);
+        
+        //! Emitted when the generator generates something
+	sigc::signal<void> progress;
+
     private:
         //! Creates the map and distributes cities, temples and ruins
         bool createMap();
@@ -237,6 +244,8 @@ class CreateScenario : public CreateScenarioRandomize
 	//start with.
 	void getBaseGold (int difficulty, int *base_gold);
 
+	void on_progress(double percent, std::string description);
+
         //data
         //for map creation
         GameScenario* d_scenario;
