@@ -26,7 +26,9 @@
 #include <list>
 #include <SDL.h>
 
-/** \brief Miscellaneous functions for unified file access
+#include "xmlhelper.h"
+
+/** \brief Miscellaneous functions for file access
   * 
   * These functions should be the sole way to access any files. They will
   * automatically prepend the correct directory, extract the correct file etc.
@@ -100,6 +102,9 @@ class File
         // Returns the filename of a music file (description or actual piece)
         static std::string getMusicFile(std::string filename);
         
+        // Returns the filename of a campaign related scenario file 
+        static std::string getCampaignFile(std::string filename);
+
         // get save game path
         static std::string getSavePath();
 
@@ -109,15 +114,12 @@ class File
         // get the available citysets
         static std::list<std::string> scanCitysets();
 
-        // get the available maps
+        // get the available scenarios
         static std::list<std::string> scanMaps();
 
-    private:
+	// get the available campaigns
+	static std::list<std::string> scanCampaigns();
 
-	static std::string getArmysetDir();
-	static std::string getTilesetDir();
-	static std::string getCitysetDir();
-	static std::string getShieldsetDir();
 };
 
 #endif //FILE_H
