@@ -234,7 +234,7 @@ bool GameMap::fill(MapGenerator* generator)
     //the sizes should definitely match, else we have a problem here
     if (width != s_width || height != s_height)
     {
-        std::cerr <<_("Error in GameMap::fillMap: sizes don't match!! Exiting.\n");
+        std::cerr << "Error in GameMap::fillMap: sizes don't match!! Exiting.\n";
         exit(-1);
     }
 
@@ -287,15 +287,19 @@ bool GameMap::save(XML_Helper* helper) const
         for (int j = 0; j < s_width; j++)
 	  {
 	    char *hexstr = NULL;
+	    int byteswritten = -1;
 	    TileStyle *style = getTile(j, i)->getTileStyle();
 	    if (largest_style_id < 256)
-	      asprintf (&hexstr, "%02x", style->getId());
+	      byteswritten = asprintf (&hexstr, "%02x", style->getId());
 	    else if (largest_style_id < 4096)
-	      asprintf (&hexstr, "%03x", style->getId());
+	      byteswritten = asprintf (&hexstr, "%03x", style->getId());
 	    else if (largest_style_id < 65536)
-	      asprintf (&hexstr, "%04x", style->getId());
-            styles << hexstr;
-	    free (hexstr);
+	      byteswritten = asprintf (&hexstr, "%04x", style->getId());
+	    if (hexstr && byteswritten > -1)
+	      {
+		styles << hexstr;
+		free (hexstr);
+	      }
 	  }
         styles <<endl;
     }
@@ -904,23 +908,27 @@ void GameMap::surroundMountains(int minx, int miny, int maxx, int maxy)
 {
   for(int j = miny; j < maxy; j++)
     for(int i = minx; i < maxx; i++)
-      if(getTile(j, i)->getMaptileType() == Tile::MOUNTAIN)
-	for(int J = -1; J <= +1; ++J)
-	  for(int I = -1; I <= +1; ++I)
-	    if((!(offmap(j+J,i+I))) &&
-	       (getTile((j+J),(i+I))->getMaptileType() != Tile::MOUNTAIN))
-	      {
-		if(getTile((j+J), (i+I))->getMaptileType() != Tile::WATER)
-		  setTile(j+J, i+I, 
-			  new Maptile (d_tileSet, j+J, i+I, 
-				       d_tileSet->getIndex(Tile::HILLS), NULL));
-		else 
-		  // water has priority here, there was some work done to conenct bodies of water
-		  // so don't break those connections.
-		  setTile(j, i, 
-			  new Maptile (d_tileSet, j, i, 
-				       d_tileSet->getIndex(Tile::HILLS), NULL));
-	      }
+      {
+	if (offmap(j, i))
+	  continue;
+	if(getTile(j, i)->getMaptileType() == Tile::MOUNTAIN)
+	  for(int J = -1; J <= +1; ++J)
+	    for(int I = -1; I <= +1; ++I)
+	      if((!(offmap(j+J,i+I))) &&
+		 (getTile((j+J),(i+I))->getMaptileType() != Tile::MOUNTAIN))
+		{
+		  if(getTile((j+J), (i+I))->getMaptileType() != Tile::WATER)
+		    setTile(j+J, i+I, 
+			    new Maptile (d_tileSet, j+J, i+I, 
+					 d_tileSet->getIndex(Tile::HILLS), NULL));
+		  else 
+		    // water has priority here, there was some work done to conenct bodies of water
+		    // so don't break those connections.
+		    setTile(j, i, 
+			    new Maptile (d_tileSet, j, i, 
+					 d_tileSet->getIndex(Tile::HILLS), NULL));
+		}
+      }
 }
 
 void GameMap::applyTileStyle (int i, int j)
@@ -940,3 +948,61 @@ void GameMap::applyTileStyle (int i, int j)
   mtile->setTileStyle(style);
 }
 
+Vector<int> GameMap::findNearestObjectInDir(Vector<int> pos, Vector<int> dir)
+{
+  std::vector<Vector<int> > objects;
+  Road *road = Roadlist::getInstance()->getNearestObjectInDir(pos, dir);
+  if (road)
+    objects.push_back(road->getPos());
+  Bridge *bridge = Bridgelist::getInstance()->getNearestObjectInDir(pos, dir);
+  if (bridge)
+    objects.push_back(bridge->getPos());
+  City *city = Citylist::getInstance()->getNearestObjectInDir(pos, dir);
+  if (city)
+    objects.push_back(city->getPos());
+  Temple *temple = Templelist::getInstance()->getNearestObjectInDir(pos, dir);
+  if (temple)
+    objects.push_back(temple->getPos());
+  Ruin *ruin = Ruinlist::getInstance()->getNearestObjectInDir(pos, dir);
+  if (ruin && ruin->isHidden() == false)
+    objects.push_back(ruin->getPos());
+  if (objects.size() == 0)
+    return Vector<int>(-1,-1);
+
+  int min_distance = -1;
+  Vector<int> closest = Vector<int>(-1,-1);
+  for (unsigned int i = 0; i < objects.size(); i++)
+    {
+      int distance = dist(pos, objects[i]);
+      if (min_distance == -1 || distance < min_distance)
+	{
+	  min_distance = distance;
+	  closest = objects[i];
+	}
+    }
+  return closest;
+}
+
+Vector<int> GameMap::findNearestObjectToTheNorth(Vector<int> pos)
+{
+  Vector<int> dir = Vector<int>(0, -1);
+  return findNearestObjectInDir(pos, dir);
+}
+
+Vector<int> GameMap::findNearestObjectToTheSouth(Vector<int> pos)
+{
+  Vector<int> dir = Vector<int>(0, 1);
+  return findNearestObjectInDir(pos, dir);
+}
+
+Vector<int> GameMap::findNearestObjectToTheEast(Vector<int> pos)
+{
+  Vector<int> dir = Vector<int>(1, 0);
+  return findNearestObjectInDir(pos, dir);
+}
+
+Vector<int> GameMap::findNearestObjectToTheWest(Vector<int> pos)
+{
+  Vector<int> dir = Vector<int>(-1, 0);
+  return findNearestObjectInDir(pos, dir);
+}
