@@ -740,7 +740,7 @@ SDL_Surface* GraphicsCache::getFlagPic(const Stack* s)
 
     if (!s)
     {
-        std::cerr <<_("GraphicsCache::getFlagPic: no stack supplied! Exiting...\n");
+        std::cerr << "GraphicsCache::getFlagPic: no stack supplied! Exiting...\n";
         exit(-1);
     }
     
@@ -773,7 +773,7 @@ SDL_Surface* GraphicsCache::getSelectorPic(Uint32 type, Uint32 frame,
 
     if (!p)
     {
-        std::cerr <<_("GraphicsCache::getSelectorPic: no player supplied! Exiting...\n");
+        std::cerr << "GraphicsCache::getSelectorPic: no player supplied! Exiting...\n";
         exit(-1);
     }
     
@@ -2389,4 +2389,3 @@ void GraphicsCache::loadFlags()
   // free the temporary surfaces
   SDL_FreeSurface(flag);
 }
-
