@@ -33,6 +33,23 @@ LocationBox::LocationBox(Vector<int> pos, Uint32 size)
 {
 }
 
+LocationBox::LocationBox(Vector<int> src, Vector<int> dest)
+    :Immovable(dist(Vector<int>(0,0), src) < dist(Vector<int>(0,0), dest) ?
+	       src : dest)
+{
+  if (dest.x > src.x)
+    d_size =  dest.x - src.x + 1;
+  else if (dest.x < src.x)
+    d_size =  src.x - dest.x + 1;
+  else
+    {
+      if (dest.y > src.y)
+	d_size =  dest.y - src.y + 1;
+      else
+	d_size =  src.y - dest.y + 1;
+    }
+}
+
 LocationBox::LocationBox(const LocationBox& loc)
   : Immovable(loc), d_size(loc.d_size)
 {
@@ -89,7 +106,7 @@ Stack* LocationBox::getFreeStack(Player *p) const
     return NULL;
 }
 
-bool LocationBox::isFogged()
+bool LocationBox::isFogged(Player *player)
 {
   for (unsigned int i = 0; i < d_size; i++)
     for (unsigned int j = 0; j < d_size; j++)
@@ -97,7 +114,7 @@ bool LocationBox::isFogged()
         Vector<int> pos;
         pos.x = getPos().x + i;
         pos.y = getPos().y + j;
-	if (FogMap::isFogged(pos))
+	if (FogMap::isFogged(pos, player))
           return true;
       }
   return false;
