@@ -31,6 +31,13 @@ class LocationBox : public Immovable
       * @param size    The number of tiles wide and high the feature is.
       */
      LocationBox(Vector<int> pos, Uint32 size = 1);
+
+     //! Non-Standard constructor.
+     /**
+      * Make a LocationBox from two points.
+      */
+     LocationBox(Vector<int> src, Vector<int> dest);
+
      //! Copy constructor.
      LocationBox(const LocationBox&);
      //! Loading constructor.
@@ -56,10 +63,9 @@ class LocationBox : public Immovable
 
     //! Returns whether or not this location obscured from view on a hidden map.
     /**
-     * @note This method relies on Playerlist::getActiveplayer to know
-     *       which FogMap to query.
+     * @param player The player whose map to query.
      */
-    bool isFogged();
+    bool isFogged(Player *player);
 
     //! Unobscures the view of this location in the active player's FogMap.
     void deFog();
