@@ -26,7 +26,6 @@
 #include "playerlist.h"
 #include "stacklist.h"
 #include "citylist.h"
-#include "defs.h"
 
 using namespace std;
 
@@ -108,7 +107,7 @@ bool QuestEnemyArmies::save(XML_Helper *helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("quest");
+    retval &= helper->openTag(Quest::d_tag);
     retval &= Quest::save(helper);
     retval &= helper->saveData("to_kill", d_to_kill);
     retval &= helper->saveData("killed",  d_killed);
