@@ -23,7 +23,6 @@
 #include "playerlist.h"
 #include "stacklist.h"
 #include "citylist.h"
-#include "defs.h"
 #include "armysetlist.h"
 
 using namespace std;
@@ -99,7 +98,7 @@ bool QuestEnemyArmytype::save(XML_Helper *helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("quest");
+    retval &= helper->openTag(Quest::d_tag);
     retval &= Quest::save(helper);
     retval &= helper->saveData("type_to_kill", d_type_to_kill);
     retval &= helper->closeTag();
