@@ -24,6 +24,7 @@
 #include "hero.h"
 #include "playerlist.h"
 #include "stacklist.h"
+#include "history.h"
 
 std::string Quest::d_tag = "quest";
 using namespace std;
@@ -101,3 +102,19 @@ bool Quest::isActive()
 
     return true;
 }
+
+std::string Quest::getHeroNameForDeadHero()
+{
+  return getHeroNameForDeadHero(d_hero);
+}
+
+std::string Quest::getHeroNameForDeadHero(Uint32 id)
+{
+  std::list<History *>events;
+  events = Playerlist::getInstance()->getHistoryForHeroId(id);
+  if (events.size() == 0)
+    return "";
+  History *history = events.front();
+  History_HeroEmerges *event = dynamic_cast<History_HeroEmerges*>(history);
+  return event->getHeroName();
+}
