@@ -219,13 +219,14 @@ void QuestsManager::questCompleted(Uint32 heroId)
     Player *p = quest->getHero()->getOwner();
 
     p->heroCompletesQuest(quest->getHero());
+    Stack *stack = p->getStacklist()->getArmyStackById(heroId);
 
     int num = rand() % 4;
     if (num == 0)
       {
 	int gold = Reward_Gold::getRandomGoldPieces();
         Reward_Gold reward(gold);
-        p->giveReward(p->getActivestack(), &reward);
+        p->giveReward(stack, &reward);
         quest_completed.emit(quest, &reward);
       }
     else if (num == 1)
@@ -233,7 +234,7 @@ void QuestsManager::questCompleted(Uint32 heroId)
         int num = (rand() % 8) + 1;
         const ArmyProto *a = Reward_Allies::randomArmyAlly();
         Reward_Allies reward(a, num);
-        p->giveReward(p->getActivestack(), &reward);
+        p->giveReward(stack, &reward);
         quest_completed.emit(quest, &reward);
 	    
 	History_HeroFindsAllies* item = new History_HeroFindsAllies();
@@ -245,14 +246,14 @@ void QuestsManager::questCompleted(Uint32 heroId)
         Reward *itemReward = Rewardlist::getInstance()->popRandomItemReward();
         if (itemReward)
           {
-            p->giveReward(p->getActivestack(), itemReward);
+            p->giveReward(stack, itemReward);
             quest_completed.emit(quest, itemReward);
           }
         else //no items left to give!
           {
 	    int gold = Reward_Gold::getRandomGoldPieces();
             Reward_Gold reward(gold);
-            p->giveReward(p->getActivestack(), &reward);
+            p->giveReward(stack, &reward);
             quest_completed.emit(quest, &reward);
           }
       }
@@ -261,14 +262,14 @@ void QuestsManager::questCompleted(Uint32 heroId)
         Reward *ruinReward = Rewardlist::getInstance()->popRandomRuinReward();
         if (ruinReward)
           {
-            p->giveReward(p->getActivestack(), ruinReward);
+            p->giveReward(stack, ruinReward);
             quest_completed.emit(quest, ruinReward);
           }
         else //no ruins left to give!
           {
             int gold = Reward_Gold::getRandomGoldPieces();
             Reward_Gold reward(gold);
-            p->giveReward(p->getActivestack(), &reward);
+            p->giveReward(stack, &reward);
             quest_completed.emit(quest, &reward);
           }
       }
@@ -278,6 +279,7 @@ void QuestsManager::questCompleted(Uint32 heroId)
     d_quests.erase(heroId);
     //debug("quest deactivated");
 }
+
 //========================================================================
 void QuestsManager::questExpired(Uint32 heroId)
 {
@@ -515,8 +517,8 @@ void QuestsManager::nextTurn(Player *p)
     {
       if ((*it)->getPlayer() == p)
 	{
-	  quest_expired.emit(*it);
 	  Quest *q = *it;
+	  quest_expired.emit(q);
 	  it = d_inactive_quests.erase(it);
 	  if (q)
 	    delete q;
