@@ -1,3 +1,8 @@
+// Copyright (C) 2004 John Farrell
+// Copyright (C) 2004 Ulf Lorenz
+// Copyright (C) 2004, 2005, 2006 Andrea Paternesi
+// Copyright (C) 2007, 2008 Ben Asselstine
+//
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
 //  the Free Software Foundation; either version 2 of the License, or
@@ -10,13 +15,15 @@
 //
 //  You should have received a copy of the GNU General Public License
 //  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 
 #ifndef THREAT_H
 #define THREAT_H
 
 #include <string>
 #include "vector.h"
+#include "Ownable.h"
 
 class City;
 class Stacklist;
@@ -47,7 +54,7 @@ class Ruin;
   * For more information about the smart AI, see ai_smart.h
   */
 
-class Threat
+class Threat: public Ownable
 {
     public:
         // CREATORS
@@ -111,13 +118,9 @@ class Threat
         //! Increase the danger of this threat 
         void addDanger(float danger) { d_danger += danger; }
 
-        //! return the player that causes this threat
-        Player *getPlayer() const { return d_player; }
-        
     private:
         City *d_city;
         Ruin *d_ruin;
-        Player *d_player;
         Stacklist *d_stacks;
         float d_danger;
 };
