@@ -97,8 +97,10 @@ void AI_Fast::abortTurn()
 
 bool AI_Fast::startTurn()
 {
+    sbusy.emit();
     AI_maybeBuyScout();
 
+    sbusy.emit();
     // maniac AI's never recruit heroes, otherwise take everything we can get
     if (!d_maniac)
       maybeRecruitHero();
@@ -139,9 +141,11 @@ bool AI_Fast::startTurn()
     if (!d_maniac)
 	AI_setupVectoring(18, 3, 30);
 
+    sbusy.emit();
     // this is a recursively-programmed quite staightforward AI,we just call:
     while (computerTurn() == true)
       {
+	sbusy.emit();
 	bool found = false;
     
 	//are there any stacks with paths that can move?
@@ -267,10 +271,6 @@ bool AI_Fast::computerTurn()
     // way round.
     for (Stacklist::reverse_iterator it = d_stacklist->rbegin(); it != d_stacklist->rend(); it++)
     {
-        // game ended; emergency stop
-        if (Playerlist::isFinished())
-            break;
-
         d_stacklist->setActivestack(*it);
         Stack* s = *it;
 	s->group();
