@@ -179,6 +179,7 @@ Army::Army(XML_Helper* helper)
       if (ival != -1)
 	d_visitedTemples.push_front(ival);
     }
+  helper->getData(d_grouped, "grouped");
 }
 
 Army::~Army()
@@ -193,8 +194,8 @@ void Army::setStat(Army::Stat stat, Uint32 value)
     {
     case STRENGTH:  
       d_strength = value;
-      if (d_strength > 9)
-	d_strength = 9;
+      if (d_strength > MAX_ARMY_STRENGTH)
+	d_strength = MAX_ARMY_STRENGTH;
       break;
     case HP:        
       d_max_hp = value;
@@ -382,8 +383,8 @@ int Army::gainLevel(Stat stat)
     {
     case STRENGTH:
       d_strength += delta;
-      if (d_strength > 9)
-	d_strength = 9;
+      if (d_strength > MAX_ARMY_STRENGTH)
+	d_strength = MAX_ARMY_STRENGTH;
       break;
     case HP:
       d_max_hp += delta;
@@ -442,6 +443,7 @@ bool Army::saveData(XML_Helper* helper) const
   for(;tit != tend;++tit)
     temples << (*tit) << " ";
   retval &= helper->saveData("visited_temples", temples.str());
+  retval &= helper->saveData("grouped", d_grouped);
 
   return retval;
 }
