@@ -27,7 +27,6 @@
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
 
-#include "defs.h"
 #include "Ownable.h"
 #include "armybase.h"
 #include "UniquelyIdentified.h"
@@ -69,6 +68,9 @@ class Army :public ArmyBase, public UniquelyIdentified, public Ownable, public s
 {
     public:
 
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
 	//! Various kinds of statistics that an instance of Army unit has.
 	/**
 	 * This enumeration assists in getting and setting of statistics in
