@@ -191,7 +191,7 @@ bool Armysetlist::loadArmyset(std::string name)
 
   if (!helper.parse())
     {
-      std::cerr <<_("Error, while loading an armyset. Armyset Name: ");
+      std::cerr << "Error, while loading an armyset. Armyset Name: ";
       std::cerr <<name <<std::endl <<std::flush;
       exit(-1);
     }
