@@ -26,6 +26,7 @@
 #include <sigc++/signal.h>
 #include <sigc++/trackable.h>
 #include <sigc++/connection.h>
+#include <string>
 
 #include "vector.h"
 #include "input-events.h"
@@ -72,6 +73,18 @@ class BigMap: public sigc::trackable
     sigc::signal<void, Rectangle> view_changed;
 
     void blank();
+
+    //! Save the whole map as one big image (bmp file).
+    bool saveAsBitmap(std::string filename);
+
+    //! Save the whole map, but not the game objects on top of it.
+    bool saveUnderlyingMapAsBitmap(std::string filename);
+
+    //! Save the current view as an image (bmp file).
+    bool saveViewAsBitmap(std::string filename);
+    void toggle_grid();
+    
+    void debugFogTile (int x, int y);
  protected:
     MapRenderer* d_renderer;
 
@@ -79,11 +92,14 @@ class BigMap: public sigc::trackable
     Vector<int> view_pos; 	// precise position of view in pixels
 
     SDL_Surface* buffer;	// the buffer we draw things in
+    SDL_Surface* magnified_buffer;	// the zoomed buffer;
+    double magnification_factor; //how much we're zoomed
     Rectangle buffer_view;	// current view of the buffer, in tiles
 
     bool input_locked;
 
     SDL_Surface* d_itempic;
+    bool d_grid_toggled;
 
     // helpers
     Vector<int> mouse_pos_to_tile(Vector<int> pos);
@@ -92,7 +108,9 @@ class BigMap: public sigc::trackable
     Vector<int> tile_to_buffer_pos(Vector<int> tile);
     Vector<int> get_view_pos_from_view();
     void draw_buffer();  
-    void blit_if_inside_buffer(const Location &obj, SDL_Surface *image);
+    bool blit_if_inside_buffer(const Location &obj, SDL_Surface *image,
+			       Rectangle &map_view, SDL_Surface *surface);
+    void blit_object(const Location &obj, SDL_Surface *image, SDL_Surface *surface);
 
     virtual void after_draw() { }
 
@@ -100,6 +118,8 @@ class BigMap: public sigc::trackable
     void draw_stack(Stack *s);
  private:
     void drawFogTile(int x, int y);
+    void draw_buffer(Rectangle map_view, SDL_Surface *surface);
+    void magnify();
 };
 
 #endif
