@@ -20,6 +20,7 @@
 #include "bridgelist.h"
 #include "xmlhelper.h"
 
+std::string Bridgelist::d_tag = "bridgelist";
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
@@ -56,17 +57,17 @@ Bridgelist::Bridgelist()
 
 Bridgelist::Bridgelist(XML_Helper* helper)
 {
-    helper->registerTag("bridge", sigc::mem_fun(this, &Bridgelist::load));
+    helper->registerTag(Bridge::d_tag, sigc::mem_fun(this, &Bridgelist::load));
 }
 
 bool Bridgelist::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("bridgelist");
+    retval &= helper->openTag(Bridgelist::d_tag);
 
     for (const_iterator it = begin(); it != end(); it++)
-        retval &= (*it).save(helper);
+        retval &= (*it)->save(helper);
     
     retval &= helper->closeTag();
 
@@ -75,13 +76,31 @@ bool Bridgelist::save(XML_Helper* helper) const
 
 bool Bridgelist::load(std::string tag, XML_Helper* helper)
 {
-    if (tag != "bridge")
+    if (tag != Bridge::d_tag)
     //what has happened?
         return false;
     
-    Bridge s(helper);
-    push_back(s);
+    push_back(new Bridge(helper));
 
     return true;
 }
 
+int Bridgelist::calculateType(Vector<int> t)
+{
+    // examine neighbour tiles to discover whether there's a bridge on them
+    bool u = Bridgelist::getInstance()->getObjectAt(t + Vector<int>(0, -1));
+    bool b = Bridgelist::getInstance()->getObjectAt(t + Vector<int>(0, 1));
+    bool l = Bridgelist::getInstance()->getObjectAt(t + Vector<int>(-1, 0));
+    bool r = Bridgelist::getInstance()->getObjectAt(t + Vector<int>(1, 0));
+
+    if (u)
+      return Bridge::CONNECTS_TO_NORTH;
+    if (b)
+      return Bridge::CONNECTS_TO_SOUTH;
+    if (r)
+      return Bridge::CONNECTS_TO_EAST;
+    if (l)
+      return Bridge::CONNECTS_TO_WEST;
+    return Bridge::CONNECTS_TO_NORTH;
+}
+
