@@ -28,9 +28,12 @@
  * is implemented as a singleton because many classes use it for looking up
  * bridges.
  */
-class Bridgelist : public LocationList<Bridge>, public sigc::trackable
+class Bridgelist : public LocationList<Bridge*>, public sigc::trackable
 {
     public:
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
         //! Return the singleton instance.  Create a new one if needed.
         static Bridgelist* getInstance();
 
@@ -43,6 +46,17 @@ class Bridgelist : public LocationList<Bridge>, public sigc::trackable
         //! Saves the list of Bridge objects to the opened saved-game file.
         bool save(XML_Helper* helper) const;
 
+	//! Determines what the right Bridge::Type should be for the given tile.
+	/**
+	 * Scans the surrounding tiles to see which bridge picture fits best.
+	 *
+	 * @param tile  The position on the game map to calculate a bridge type
+	 *              for.
+	 *
+	 * @return The Bridge::Type that makes the most sense for the given 
+	 *         tile.
+	 */
+	int calculateType(Vector<int> t);
     protected:
         //! Default constructor.
         Bridgelist();
