@@ -22,6 +22,7 @@
 #include "vector.h"
 #include "Location.h"
 #include "Renamable.h"
+#include <string>
 
 //! Scenario Editor.  A game object that has a position and a changeable name.
 class RenamableLocation: public Location, public Renamable
@@ -31,6 +32,12 @@ class RenamableLocation: public Location, public Renamable
      RenamableLocation(Vector<int> pos);
      //! Destructor.
     ~RenamableLocation();
+
+    std::string getDescription() const {return d_description;};
+    void setDescription(std::string desc) {d_description = desc;};
+
+ private:
+    std::string d_description;
 };
 
 #endif
