@@ -24,10 +24,10 @@
 #include <time.h>
 #include <gtkmm/main.h>
 
-#include "../Configuration.h"
-#include "../File.h"
-#include "../GraphicsCache.h"
-#include "../timing.h"
+#include "Configuration.h"
+#include "File.h"
+#include "GraphicsCache.h"
+#include "timing.h"
 
 #include "armyset-window.h"
 
@@ -39,11 +39,6 @@ int main(int argc, char* argv[])
     initialize_configuration();
 
     setlocale(LC_ALL, Configuration::s_lang.c_str());
-#ifndef __WIN32__
-    bindtextdomain ("lordsawar",PO_PATH);
-#else
-    bindtextdomain ("lordsawar","./locale/");
-#endif
     textdomain ("lordsawar");
 
     // Check if armysets are in the path (otherwise exit)
