@@ -25,12 +25,12 @@
 
 #include "glade-helpers.h"
 #include "image-helpers.h"
-#include "../ucompose.hpp"
-#include "../defs.h"
-#include "../army.h"
-#include "../armysetlist.h"
-#include "../player.h"
-#include "../GraphicsCache.h"
+#include "ucompose.hpp"
+#include "defs.h"
+#include "army.h"
+#include "armysetlist.h"
+#include "player.h"
+#include "GraphicsCache.h"
 
 ArmyBonusDialog::ArmyBonusDialog(Player *p)
 {
@@ -42,6 +42,8 @@ ArmyBonusDialog::ArmyBonusDialog(Player *p)
     Gtk::Dialog *d = 0;
     xml->get_widget("dialog", d);
     dialog.reset(d);
+    decorate(dialog.get());
+    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
 
     armies_list = Gtk::ListStore::create(armies_columns);
     xml->get_widget("treeview", armies_treeview);
@@ -89,7 +91,7 @@ void ArmyBonusDialog::addArmyType(Uint32 army_type)
 {
     GraphicsCache *gc = GraphicsCache::getInstance();
     Player *p = d_player;
-    const Army *a;
+    const ArmyProto *a;
     a = Armysetlist::getInstance()->getArmy(p->getArmyset(), army_type);
     if (a->isHero())
       return; //we don't want to show heroes in this list
@@ -98,9 +100,9 @@ void ArmyBonusDialog::addArmyType(Uint32 army_type)
     (*i)[armies_columns.image] = to_pixbuf(gc->getArmyPic(p->getArmyset(),
                                            army_type,
                                            p, NULL));
-    (*i)[armies_columns.str] = a->getStat(Army::STRENGTH, false);
-    (*i)[armies_columns.move] = a->getStat(Army::MOVES, false);
-    Uint32 b = a->getStat(Army::MOVE_BONUS, false);
+    (*i)[armies_columns.str] = a->getStrength();
+    (*i)[armies_columns.move] = a->getMaxMoves();
+    Uint32 b = a->getMoveBonus();
     (*i)[armies_columns.move_image] = to_pixbuf(gc->getMoveBonusPic(b, false));
     (*i)[armies_columns.bonus] = "-";
 
