@@ -27,17 +27,19 @@
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/entry.h>
 
-#include "../heromap.h"
-#include "../player.h"
-#include "../hero.h"
+#include "heromap.h"
+#include "player.h"
+#include "hero.h"
+#include "heroproto.h"
 
+#include "decorated.h"
 struct SDL_Surface;
 
 //! dialog for accepting/rejecting a hero
-class HeroOfferDialog: public sigc::trackable
+class HeroOfferDialog: public Decorated
 {
  public:
-    HeroOfferDialog(Player *player, Hero *hero, City *city, int gold);
+    HeroOfferDialog(Player *player, HeroProto *hero, City *city, int gold);
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -54,7 +56,7 @@ class HeroOfferDialog: public sigc::trackable
     Gtk::RadioButton *male_radiobutton;
     Gtk::Entry *name_entry;
     
-    Hero *hero;
+    HeroProto *hero;
     City *city;
 
     void on_male_toggled();
