@@ -1,5 +1,5 @@
 //  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -101,7 +101,10 @@ bool Main::iterate_main_loop()
 void Main::start_main_loop()
 {
     if (Configuration::s_decorated)
+      {
       Gtk::RC::add_default_file(File::getMiscFile("gtkrc"));
+	Gtk::RC::reparse_all(Gtk::Settings::get_default(), true);
+      }
 
     try
     {
