@@ -1,3 +1,20 @@
+//  Copyright (C) 2008, 2009 Ben Asselstine
+//
+//  This program is free software; you can redistribute it and/or modify
+//  it under the terms of the GNU General Public License as published by
+//  the Free Software Foundation; either version 2 of the License, or
+//  (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU Library General Public License for more details.
+//
+//  You should have received a copy of the GNU General Public License
+//  along with this program; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
+
 #include "new-game-progress-window.h"
 #include "GameScenario.h"
 #include "driver.h"
@@ -18,31 +35,24 @@ NewGameProgressWindow::NewGameProgressWindow(GameParameters g, GameScenario::Pla
   m_vbox.pack_start(m_pbar);
   property_default_width() = 320;
  
-  m_dispatcher.connect( sigc::mem_fun( m_pbar , &Gtk::ProgressBar::pulse ));
+  //m_dispatcher.connect( sigc::mem_fun( m_pbar , &Gtk::ProgressBar::pulse ));
 
   set_title(_("Please wait..."));
   m_label.set_text(_("Generating."));
   d_game_scenario = NULL;
-  m_thread = Glib::Thread::create( sigc::mem_fun(*this,&NewGameProgressWindow::thread_worker),true);
+  //m_thread = Glib::Thread::create( sigc::mem_fun(*this,&NewGameProgressWindow::thread_worker),true);
   show_all();
 }
 
 NewGameProgressWindow::~NewGameProgressWindow()
 {
-  {
-    Glib::Mutex::Lock lock(mutex);                    
-    if(m_end_thread == false)
-       m_end_thread = true;
-  }
-  if(m_thread->joinable())
-    m_thread->join();
 }
 
 void NewGameProgressWindow::thread_worker()
 {
   s_instance = this;
   bool update_uuid = false;
-  m_dispatcher();
+  //m_dispatcher();
   sleep(2);
   if (game_params.map_path.empty()) 
     {
@@ -86,33 +96,25 @@ void NewGameProgressWindow::thread_worker()
 
       Playerlist::getInstance()->syncPlayers(game_params.players);
 
-      m_dispatcher();
+      //m_dispatcher();
 
       game_scenario->initialize(game_params);
 
-      m_dispatcher();
+      //m_dispatcher();
 
     }
 
   d_game_scenario = game_scenario;
 
-  m_dispatcher();
+  //m_dispatcher();
 
-    {
-      Glib::Mutex::Lock lock(mutex);
-      if(m_end_thread)
-	{
-	  s_instance = NULL;
-  	  return;
-	}
-    }
   hide();
   s_instance = NULL;
 }
 
 void NewGameProgressWindow::pulse()
 {
-  m_dispatcher();
+  //m_dispatcher();
 }
 
 NewGameProgressWindow * NewGameProgressWindow::getInstance()
