@@ -57,29 +57,50 @@ PreferencesDialog::PreferencesDialog(bool readonly)
     xml->get_widget("players_vbox", players_vbox);
     
     GraphicsCache *gc = GraphicsCache::getInstance();
-    Playerlist* pl = Playerlist::getInstance();
-    for (Playerlist::iterator i = pl->begin(); i != pl->end(); ++i)
+    for (unsigned int i = 0; i < MAX_PLAYERS; i++)
       {
-	if (*i == Playerlist::getInstance()->getNeutral())
+	Player *p = Playerlist::getInstance()->getPlayer(i);
+	if (p == NULL)
+	  continue;
+	if (p == Playerlist::getInstance()->getNeutral())
 	  continue;
 	Gtk::HBox *player_hbox = new Gtk::HBox();
-	Gtk::Image *image = new Gtk::Image(to_pixbuf(gc->getShieldPic(2, *i)));
+	Gtk::Image *image = new Gtk::Image(to_pixbuf(gc->getShieldPic(2, p)));
 	Gtk::ComboBoxText *type = new Gtk::ComboBoxText();
+	type->signal_changed().connect
+	  (sigc::bind(sigc::mem_fun
+		      (this, &PreferencesDialog::on_type_changed), type));
+	Gtk::CheckButton *observe = new Gtk::CheckButton(_("Observe"));
+	observe->signal_toggled().connect
+	  (sigc::bind(sigc::mem_fun
+		      (this, &PreferencesDialog::on_observe_toggled), observe));
+
+	observe->set_active(p->isObservable());
 	type->append_text(_("Human"));
 	type->append_text(_("Computer"));
-	if ((*i)->getType() == Player::HUMAN)
-	  type->set_active(0);
+	if (p->getType() == Player::HUMAN)
+	  {
+	    observe->set_sensitive(false);
+	    type->set_active(0);
+	  }
 	else
 	  type->set_active(1);
-	if ((*i)->isDead())
-	  type->set_sensitive(false);
+	if (p->isDead())
+	  {
+	    type->set_sensitive(false);
+	    observe->set_sensitive(false);
+	  }
 	if (readonly)
 	  type->set_sensitive(false);
 	player_hbox->pack_start(*manage(image), Gtk::PACK_SHRINK, 
 				Gtk::PACK_SHRINK);
 	player_hbox->pack_start(*manage(type), Gtk::PACK_SHRINK, 10);
-	player_types.push_back(type);
-	Gtk::Label *player_name = new Gtk::Label((*i)->getName());
+	player_hbox->pack_start(*manage(observe), Gtk::PACK_SHRINK, 10);
+	//player_types.push_back(type);
+	player_types[p] = type;
+	player_observed[p] = observe;
+	//player_observed.push_back(observe);
+	Gtk::Label *player_name = new Gtk::Label(p->getName());
 	player_hbox->pack_start(*manage(player_name), Gtk::PACK_SHRINK, 10);
 	players_vbox->pack_start(*manage(player_hbox));
       }
@@ -104,6 +125,42 @@ void PreferencesDialog::set_parent_window(Gtk::Window &parent)
     //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
+void PreferencesDialog::on_type_changed(Gtk::ComboBoxText *combo)
+{
+  for (PlayerTypeMap::iterator it = player_types.begin();
+       it != player_types.end(); it++)
+    {
+      if (combo == (*it).second)
+	{
+	  /**
+	   * if we're turning this player into a human,
+	   * then we desensitize the associated checkbutton
+	   * otherwise, we presume that we want to observe it
+	   */
+	  if (combo->get_active_text() == _("Human"))
+	    {
+	      player_observed[(*it).first]->set_active(true);
+	      player_observed[(*it).first]->set_sensitive(false);
+	    }
+	  else
+	    {
+	      player_observed[(*it).first]->set_sensitive(true);
+	      player_observed[(*it).first]->set_active(true);
+	    }
+	}
+    }
+}
+
+void PreferencesDialog::on_observe_toggled(Gtk::CheckButton *button)
+{
+  for (PlayerObserveMap::iterator it = player_observed.begin();
+       it != player_observed.end(); it++)
+    {
+      if (button == (*it).second)
+	(*it).first->setObservable(button->get_active());
+    }
+}
+
 void PreferencesDialog::hide()
 {
   dialog->hide();
@@ -122,21 +179,22 @@ void PreferencesDialog::run(Game *game)
     
     dialog->get_size(width, height);
     Configuration::saveConfigurationFile(Configuration::configuration_file_path);
-    Playerlist* pl = Playerlist::getInstance();
-    std::list<Gtk::ComboBoxText *>::iterator j = player_types.begin();
-    Playerlist::iterator i = pl->begin();
-    for (; j != player_types.end(); ++i, ++j)
+    PlayerTypeMap::iterator j = player_types.begin();
+    for (; j != player_types.end(); ++j)
       {
-	if ((*i) == Playerlist::getInstance()->getNeutral())
-	  i++;
-	if ((*i)->getType() == Player::HUMAN) //changing human to:
+	Player *p = (*j).first;
+	if (p == NULL)
+	  continue;
+	if (p == Playerlist::getInstance()->getNeutral())
+	  continue;
+	if (p->getType() == Player::HUMAN) //changing human to:
 	  {
-	    if ((*j)->get_active_text() == _("Human")) //human, no change
+	    if ((*j).second->get_active_text() == _("Human")) //human, no change
 	      ;
 	    else //computer, change to easy
 	      {
-		AI_Fast *new_player = new AI_Fast(**i);
-		Player *old_player = *i;
+		AI_Fast *new_player = new AI_Fast(*p);
+		Player *old_player = p;
 		Playerlist::getInstance()->swap(old_player, new_player);
 		//disconnect and connect game signals
 		game->addPlayer(new_player);
@@ -144,10 +202,10 @@ void PreferencesDialog::run(Game *game)
 	  }
 	else //changing computer to:
 	  {
-	    if ((*j)->get_active_text() == _("Human")) //human, change it
+	    if ((*j).second->get_active_text() == _("Human")) //human, change it
 	      {
-		RealPlayer *new_player = new RealPlayer(**i);
-		Player *old_player = *i;
+		RealPlayer *new_player = new RealPlayer(*p);
+		Player *old_player = p;
 		Playerlist::getInstance()->swap(old_player, new_player);
 		//disconnect and connect game signals
 		game->addPlayer(new_player);
