@@ -116,7 +116,7 @@ QuestCompletedDialog::QuestCompletedDialog(Quest *q, Reward *r)
 	else if (ruin_reward->getType() == Reward::MAP)
 	  s += _("where a map can be found!");
 	else if (ruin_reward->getType() == Reward::RUIN)
-	  s += _("where crapola can be found!");
+	  s += _("where nothing can be found!");
 	else if (ruin_reward->getType() == Reward::GOLD)
 	  s += _("where gold can be found!");
 	else //this one shouldn't happen
