@@ -116,7 +116,7 @@ void SageDialog::hide()
 Reward *SageDialog::run()
 {
     ruinmap->resize();
-    ruinmap->draw();
+    ruinmap->draw(Playerlist::getActiveplayer());
 
     Sound::getInstance()->playMusic("hero", 1);
     dialog->show_all();
