@@ -55,6 +55,7 @@ class SplashWindow: public Decorated
     sigc::signal<void, GameParameters, int, std::string > new_hosted_network_game_requested;
     sigc::signal<void, GameParameters> new_pbm_game_requested;
     sigc::signal<void, GameParameters> new_game_requested;
+    sigc::signal<void, GameParameters> new_campaign_requested;
     sigc::signal<void, std::string> load_requested;
     sigc::signal<void> quit_requested;
 
@@ -81,6 +82,7 @@ class SplashWindow: public Decorated
     void on_rescue_crashed_game_clicked();
 	
     void on_game_started(GameParameters g);
+    void on_campaign_started(GameParameters g);
     void on_network_game_created(GameParameters g);
     void on_pbm_game_created(GameParameters g);
     void on_network_game_selected(std::string ip, unsigned short port);
