@@ -25,15 +25,15 @@
 #include "glade-helpers.h"
 #include "input-helpers.h"
 #include "image-helpers.h"
-#include "../ucompose.hpp"
-#include "../defs.h"
-#include "../army.h"
-#include "../player.h"
-#include "../armysetlist.h"
-#include "../playerlist.h"
-#include "../stack.h"
-#include "../GraphicsCache.h"
-#include "../Tile.h"
+#include "ucompose.hpp"
+#include "defs.h"
+#include "army.h"
+#include "player.h"
+#include "armysetlist.h"
+#include "playerlist.h"
+#include "stack.h"
+#include "GraphicsCache.h"
+#include "Tile.h"
 #include <assert.h>
 
 StackInfoDialog::StackInfoDialog(Stack *s)
@@ -47,6 +47,8 @@ StackInfoDialog::StackInfoDialog(Stack *s)
     Gtk::Dialog *d = 0;
     xml->get_widget("dialog", d);
     dialog.reset(d);
+    decorate(dialog.get());
+    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
 
     xml->get_widget("stack_table", stack_table);
 
@@ -92,7 +94,7 @@ void StackInfoDialog::addArmy (Army *h, Uint32 modified_strength, int idx)
     
   Gtk::ToggleButton *toggle = manage(new Gtk::ToggleButton);
   Glib::RefPtr<Gdk::Pixbuf> pixbuf = 
-    to_pixbuf(gc->getArmyPic(player->getArmyset(), h->getType(), player, 
+    to_pixbuf(gc->getArmyPic(player->getArmyset(), h->getTypeId(), player, 
 			     NULL));
   
   Gtk::Image *image = NULL;
@@ -224,8 +226,7 @@ bool StackInfoDialog::on_army_button_event(GdkEventButton *e, Gtk::ToggleButton
       const Army *army = armies[slot];
 
       if (army)
-	army_info_tip.reset(new ArmyInfoTip(toggle, army, 
-					    ArmyInfoTip::ARMY_INSTANCE));
+	army_info_tip.reset(new ArmyInfoTip(toggle, army));
       return true;
     }
   else if (event.button == MouseButtonEvent::RIGHT_BUTTON
