@@ -28,8 +28,10 @@
 
 struct SDL_Surface;
 
+#include "decorated.h"
+
 // dialog for accepting/rejecting surrender from computer players
-class SurrenderDialog: public sigc::trackable
+class SurrenderDialog: public Decorated
 {
  public:
     SurrenderDialog(int numPlayers);
