@@ -1,4 +1,4 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //  Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 #include "playerlist.h"
 #include "hero.h"
 #include "heroproto.h"
+#include <sstream>
 
 HeroTemplates* HeroTemplates::d_instance = 0;
 
@@ -64,15 +65,6 @@ HeroProto *HeroTemplates::getRandomHero(int player_id)
 
 int HeroTemplates::loadHeroTemplates()
 {
-  FILE *fileptr = fopen (File::getMiscFile("heronames").c_str(), "r");
-  char *line = NULL;
-  size_t len = 0;
-  ssize_t read;
-  int retval;
-  int gender;
-  int side;
-  size_t bytesread = 0;
-  char *tmp;
   const Armysetlist* al = Armysetlist::getInstance();
   const ArmyProto* herotype;
 
@@ -85,46 +77,35 @@ int HeroTemplates::loadHeroTemplates()
       if (a->isHero())
 	heroes.push_back(a);
     }
-
-  if (fileptr == NULL)
-    return -1;
-  while ((read = getline (&line, &len, fileptr)) != -1)
+  std::ifstream file(File::getMiscFile("heronames").c_str());
+  if (file.good()) 
     {
-      bytesread = 0;
-      retval = sscanf (line, "%d%d%n", &side, &gender, &bytesread);
-      if (retval != 2)
-	{
-	  free (line);
-	  return -2;
-	}
-      while (isspace(line[bytesread]) && line[bytesread] != '\0')
-	bytesread++;
-      tmp = strchr (&line[bytesread], '\n');
-      if (tmp)
-	tmp[0] = '\0';
-      if (strlen (&line[bytesread]) == 0)
-	{
-	  free (line);
-	  return -3;
-	}
-      if (side < 0 || side > (int) MAX_PLAYERS)
-	{
-	  free (line);
-	  return -4;
-	}
+      std::string buffer, name;
+      int side, gender;
 
-      herotype = heroes[rand() % heroes.size()];
-      HeroProto *newhero = new HeroProto (*herotype);
-      if (gender)
-	newhero->setGender(Hero::MALE);
-      else
-	newhero->setGender(Hero::FEMALE);
-      newhero->setName (&line[bytesread]);
-      d_herotemplates[side].push_back (newhero);
+      while (std::getline(file, buffer)) 
+	{
+	  std::istringstream line(buffer);
+	  if (!(line >> side >> gender >> name))
+	    return -2;
+
+	  if (side < 0 || side > (int) MAX_PLAYERS)
+	    return -4;
+
+	  herotype = heroes[rand() % heroes.size()];
+	  HeroProto *newhero = new HeroProto (*herotype);
+	  if (gender)
+	    newhero->setGender(Hero::MALE);
+	  else
+	    newhero->setGender(Hero::FEMALE);
+
+	  newhero->setName (name);
+	  d_herotemplates[side].push_back (newhero);
+	}
     }
-  if (line)
-    free (line);
-  fclose (fileptr);
+  else
+    return -1;
+  file.close();
   return 0;
 }
-        
+
