@@ -229,7 +229,17 @@ Uint32 Path::calculateToCity (Stack *s, Location *c, bool zigzag)
   return mp;
 }
 
-Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
+bool Path::load_or_unload(Stack *s, Vector<int> src, Vector<int> dest, bool &on_ship)
+{
+  //do we load or unload if we step from SRC to DEST?
+  Vector<int> old = s->getPos();
+  s->setPos(src);
+  bool retval = s->isMovingToOrFromAShip(dest, on_ship);
+  s->setPos(old);
+  return retval;
+}
+
+void Path::calculate (Stack* s, Vector<int> dest, Uint32 &moves, Uint32 &turns, bool zigzag)
 {
   int mp;
   Vector<int> start = s->getPos();
@@ -245,11 +255,16 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
 	setMovesExhaustedAtPoint(1);
       else
 	setMovesExhaustedAtPoint(0);
-      return 1;
+      moves = 1;
+      turns = 0;
+      return;
     }
   int width = GameMap::getWidth();
   int height = GameMap::getHeight();
   d_bonus = s->calculateMoveBonus();
+  int land_reset_moves = s->getMaxGroupLandMoves();
+  int boat_reset_moves = s->getMaxGroupBoatMoves();
+
   //if (isBlocked(s, dest.x, dest.y, dest.x, dest.y))
   //{
   //s->setMovesExhaustedAtPoint(0);
@@ -257,7 +272,7 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
   //}
 
   // Some notes concerning the path finding algorithm. The algorithm
-  // uses two different lists. There is a distance array, which contains how
+  // uses two different lists. There is a nodes array, which contains how
   // many MP one needs to get to the location (x,y), and a process queue that
   // tells you at what point the number of movement points is calculated next.
   //
@@ -278,21 +293,32 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
   // the conversion between x/y coordinates and index is (size is map size)
   // index = y*width + x    <=>    x = index % width;   y = index / width
   int length = width*height;
-  int distance[length];
+  struct node
+    {
+      int moves;
+      int turns;
+      int moves_left;
+    };
+  struct node nodes[length];
   std::queue<Vector<int> > process;
   bool flying = s->isFlying();
+  bool on_ship = s->hasShip();
 
-  // initial filling of the distance vector
+  // initial filling of the nodes vector
   for (int i = 0; i < width*height; i++)
     {
       // -1 means don't know yet
       // -2 means can't go there at all
       // 0 or more is number of movement points needed to get there
-      distance[i] = -1;
+      nodes[i].moves = -1;
+      nodes[i].moves_left = 0;
+      nodes[i].turns = 0;
       if (isBlocked(s, i % width, i/width, dest.x, dest.y))
-	distance[i] = -2;
+	nodes[i].moves = -2;
     }
-  distance[start.y*width+start.x] = 0;
+  nodes[start.y*width+start.x].moves = 0;
+  nodes[start.y*width+start.x].moves_left = s->getGroupMoves();
+  nodes[start.y*width+start.x].turns = 0;
 
   // now the main loop
   process.push(Vector<int>(start.x, start.y));
@@ -301,7 +327,7 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
       Vector<int> pos = process.front();
       process.pop();                          // remove the first item
 
-      int dxy = distance[pos.y*width+pos.x];   // always >= 0
+      int dxy = nodes[pos.y*width+pos.x].moves;   // always >= 0
 
       for (int sx = pos.x-1; sx <= pos.x+1; sx++)
 	{
@@ -325,7 +351,7 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
 		  == Tile::VOID)
 		continue;
 
-	      int dsxy = distance[sy*width+sx];
+	      int dsxy = nodes[sy*width+sx].moves;
 	      if (dsxy < -1)
 		continue; // can't move there anyway
 
@@ -337,12 +363,27 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
 		}
 	      int newDsxy = dxy;
 	      mp = pointsToMoveTo(s, pos.x, pos.y, sx, sy);
-	      if (mp >= 0)
-		newDsxy += mp;
+	      if (mp < 0)
+		mp = 0;
+	      if (!flying && load_or_unload(s, pos, Vector<int>(sx, sy), on_ship) == true)
+		mp = nodes[pos.y*width+pos.x].moves_left;
+	      newDsxy += mp;
+
 
 	      if (dsxy == -1 || dsxy > newDsxy)
 		{
-		  distance[sy*width+sx] = newDsxy;
+		  nodes[sy*width+sx].moves = newDsxy;
+		  nodes[sy*width+sx].moves_left = 
+		    nodes[pos.y*width+pos.x].moves_left - mp;
+		  nodes[sy*width+sx].turns = nodes[pos.y*width+pos.x].turns ;
+		  while (nodes[sy*width+sx].moves_left <= 0)
+		    {
+		      if (on_ship)
+			nodes[sy*width+sx].moves_left += boat_reset_moves;
+		      else
+			nodes[sy*width+sx].moves_left += land_reset_moves;
+		      nodes[sy*width+sx].turns++;
+		    }
 
 		  // append the item to the queue
 		  process.push(Vector<int>(sx, sy));
@@ -351,16 +392,18 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
 	}
     }
 
-  // The distance array is now completely populated.
+  // The nodes array is now completely populated.
   // What we have to do now is find the shortest path to the destination.
   // We do that by starting at the destination and moving at each step to
   // the neighbour closest to the start.
 
-  int dist = distance[dest.y * width + dest.x];
+  int dist = nodes[dest.y * width + dest.x].moves;
   if (dist < 0)
     {
       setMovesExhaustedAtPoint(0);
-      return 0;
+      moves = 0;
+      turns = 0;
+      return;
     }
 
   // choose the order in which we process directions so as to favour
@@ -407,7 +450,7 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
 	  if (!flying && isBlockedDir(x, y, newx, newy))
 	    continue;
 
-	  dist = distance[newy*width+newx];
+	  dist = nodes[newy*width+newx].moves;
 	  if (dist >= 0 && dist < min)
 	    {
 	      rx = newx;
@@ -436,7 +479,24 @@ Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
   setMovesExhaustedAtPoint(pathcount);
 
   debug("...done");
-  return distance[dest.y * width + dest.x];
+  moves = nodes[dest.y * width + dest.x].moves;
+  turns = nodes[dest.y * width + dest.x].turns;
+  return;
+}
+
+Uint32 Path::calculate (Stack* s, Vector<int> dest, Uint32 &turns, bool zigzag)
+{
+  Uint32 mp = 0;
+  calculate(s, dest, mp, turns, zigzag);
+  return mp;
+}
+
+Uint32 Path::calculate (Stack* s, Vector<int> dest, bool zigzag)
+{
+  Uint32 mp = 0;
+  Uint32 turns = 0;
+  calculate(s, dest, mp, turns, zigzag);
+  return mp;
 }
 
 void Path::eraseFirstPoint()
