@@ -736,8 +736,8 @@ bool Player::stackJoin(Stack* receiver, Stack* joining, bool grouped)
     if (joining->canJoin(receiver) == false)
       {
 	//fixme: this is a bad idea.  it seems recursively bad.
-	Stack *already_there = Stacklist::getAmbiguity(joining);
-	stackJoin(joining, already_there,  false);
+	//Stack *already_there = Stacklist::getAmbiguity(joining);
+	//doStackJoin(joining, already_there,  false);
         return false;
       }
     
@@ -858,7 +858,7 @@ MoveResult *Player::stackMove(Stack* s, Vector<int> dest, bool follow)
     }
 
     int stepCount = 0;
-    while (s->getPath()->size() > 1 && stackMoveOneStep(s) ||
+    while ((s->getPath()->size() > 1 && stackMoveOneStep(s)) ||
 	   stackMoveOneStepOverTooLargeFriendlyStacks(s))
       {
 	stepCount++;
@@ -1284,7 +1284,7 @@ Reward* Player::stackSearchRuin(Stack* s, Ruin* r)
   if ((s->getPos().x != r->getPos().x) ||
       (s->getPos().y != r->getPos().y))
   {
-    cerr <<_("Error: searching stack and ruin to be searched not on same position\n");
+    cerr <<  "Error: searching stack and ruin to be searched not on same position\n" ;
     exit(-1);
   }
 
@@ -1373,7 +1373,7 @@ Quest* Player::stackGetQuest(Stack* s, Temple* t, bool except_raze)
     if (!s || !t || (s->getPos().x != t->getPos().x) 
 	|| (s->getPos().y != t->getPos().y))
       {
-	cerr <<_("Stack tried to visit temple at wrong location\n");
+	cerr << "Stack tried to visit temple at wrong location\n";
 	exit(-1);
       }
 
@@ -1449,34 +1449,33 @@ void Player::adjustDiplomacyFromConqueringCity(City *city)
   }
 }
 
-int Player::lootCity(City *city)
+void Player::calculateLoot(Player *looted, Uint32 &added, Uint32 &subtracted)
 {
-  Player *defender = city->getOwner();
+  Player *defender = looted;
   int gold = 0;
 
   // if the attacked city isn't neutral, loot some gold
   if (defender != Playerlist::getInstance()->getNeutral())
   {
     Citylist *clist = Citylist::getInstance();
-    int amt = (defender->getGold() / (2 * clist->countCities (defender)) * 2);
+    int amt = (defender->getGold() / (2 * (clist->countCities (defender)+1)) * 2);
     // give (Enemy-Gold/(2Enemy-Cities)) to the attacker 
     // and then take away twice that from the defender.
     // the idea here is that some money is taken in the invasion
     // and other monies are lost forever
-    defender->withdrawGold (amt);
+    // NOTE: +1 because the looted player just lost a city
+    subtracted = amt;
     amt /= 2;
-    addGold (amt);
+    added = amt;
     gold = amt;
   }
 
-  return gold;
+  return;
 }
 
 void Player::doConquerCity(City *city, Stack *stack)
 {
-  int gold = lootCity(city);
   takeCityInPossession(city);
-  sinvadingCity.emit(city, gold);
   
   History_CityWon *item = new History_CityWon();
   item->fillData(city);
@@ -1497,7 +1496,30 @@ void Player::conquerCity(City *city, Stack *stack)
   action->fillData(city, stack);
   addAction(action);
 
+  Player *looted = city->getOwner();
   doConquerCity(city, stack);
+  if (getType() != Player::NETWORKED)
+    lootCity(city, looted);
+}
+
+void Player::lootCity(City *city, Player *looted)
+{
+  Uint32 added = 0;
+  Uint32 subtracted = 0;
+  calculateLoot(looted, added, subtracted);
+  sinvadingCity.emit(city, added);
+  doLootCity(looted, added, subtracted);
+  Action_Loot *item = new Action_Loot();
+  item->fillData(this, looted, added, subtracted);
+  addAction(item);
+  return;
+}
+
+void Player::doLootCity(Player *looted, Uint32 added, Uint32 subtracted)
+{
+  addGold(added);
+  looted->withdrawGold(subtracted);
+  return;
 }
 
 void Player::takeCityInPossession(City* c)
@@ -1781,6 +1803,7 @@ bool Player::giveReward(Stack *s, Reward *reward)
   item->fillData(s, reward);
   addAction(item);
   //FIXME: get rid of this reward now that we're done with it
+  //but we need to show it still... (in the case of quest completions)
 
   return true;
 }
@@ -2295,11 +2318,14 @@ void Player::recruitHero(HeroProto* heroproto, City *city, int cost, int alliesC
   Action_RecruitHero *action = new Action_RecruitHero();
   action->fillData(heroproto, city, cost, alliesCount, ally);
   addAction(action);
-  History_HeroEmerges *item = new History_HeroEmerges();
-  item->fillData(heroproto, city);
-  addHistory(item);
 
-  doRecruitHero(heroproto, city, cost, alliesCount, ally);
+  Hero *hero = doRecruitHero(heroproto, city, cost, alliesCount, ally);
+  if (hero)
+    {
+      History_HeroEmerges *item = new History_HeroEmerges();
+      item->fillData(hero, city);
+      addHistory(item);
+    }
 }
 
 void Player::doDeclareDiplomacy (DiplomaticState state, Player *player)
@@ -3175,4 +3201,122 @@ bool Player::conqueredCity(City *c)
     }    
   return false;
 }
+
+std::list<Vector<int> > Player::getStackTrack(Stack *s)
+{
+  std::list<Vector<int> > points;
+  Vector<int> delta = Vector<int>(0,0);
+  for (list<Action*>::const_iterator it = d_actions.begin();
+       it != d_actions.end(); it++)
+    {
+      if ((*it)->getType() == Action::STACK_MOVE)
+	{
+	  Action_Move *action = dynamic_cast<Action_Move*>(*it);
+	  if (action->getStackId() == s->getId())
+	    {
+	      if (points.size() == 0)
+		delta = action->getPositionDelta();
+	      points.push_back(action->getEndingPosition());
+	    }
+	}
+    }
+  if (points.size() >= 1)
+    {
+      Vector<int> pos = points.front() + delta;
+      if (pos != points.front())
+	points.push_front(pos);
+    }
+  return points;
+}
+	
+std::list<History *>Player::getHistoryForHeroId(Uint32 id)
+{
+  std::string hero_name = "";
+  std::list<History*> events;
+  std::list<History*>::const_iterator pit;
+  for (pit = d_history.begin(); pit != d_history.end(); pit++)
+    {
+      switch ((*pit)->getType())
+	{
+	case History::HERO_EMERGES:
+	    {
+	      History_HeroEmerges *event;
+	      event = dynamic_cast<History_HeroEmerges *>(*pit);
+	      if (event->getHeroId() == id)
+		{
+		  hero_name = event->getHeroName();
+		  events.push_back(*pit);
+		}
+	      break;
+	    }
+	case History::FOUND_SAGE:
+	    {
+	      History_FoundSage *event;
+	      event = dynamic_cast<History_FoundSage*>(*pit);
+	      if (event->getHeroName() == hero_name)
+		events.push_back(*pit);
+	      break;
+	    }
+	case History::HERO_QUEST_STARTED:
+	    {
+	      History_HeroQuestStarted *event;
+	      event = dynamic_cast<History_HeroQuestStarted*>(*pit);
+	      if (event->getHeroName() == hero_name)
+		events.push_back(*pit);
+	      break;
+	    }
+	case History::HERO_QUEST_COMPLETED:
+	    {
+	      History_HeroQuestCompleted *event;
+	      event = dynamic_cast<History_HeroQuestCompleted*>(*pit);
+	      if (event->getHeroName() == hero_name)
+		events.push_back(*pit);
+	      break;
+	    }
+	case History::HERO_KILLED_IN_CITY:
+	    {
+	      History_HeroKilledInCity *event;
+	      event = dynamic_cast<History_HeroKilledInCity*>(*pit);
+	      if (event->getHeroName() == hero_name)
+		events.push_back(*pit);
+	      break;
+	    }
+	case History::HERO_KILLED_IN_BATTLE:
+	    {
+	      History_HeroKilledInBattle *event;
+	      event = dynamic_cast<History_HeroKilledInBattle*>(*pit);
+	      if (event->getHeroName() == hero_name)
+		events.push_back(*pit);
+	      break;
+	    }
+	case History::HERO_KILLED_SEARCHING:
+	    {
+	      History_HeroKilledSearching*event;
+	      event = dynamic_cast<History_HeroKilledSearching*>(*pit);
+	      if (event->getHeroName() == hero_name)
+		events.push_back(*pit);
+	      break;
+	    }
+	case History::HERO_CITY_WON:
+	    {
+	      History_HeroCityWon *event;
+	      event = dynamic_cast<History_HeroCityWon*>(*pit);
+	      if (event->getHeroName() == hero_name)
+		events.push_back(*pit);
+	      break;
+	    }
+	case History::HERO_FINDS_ALLIES:
+	    {
+	      History_HeroFindsAllies *event;
+	      event = dynamic_cast<History_HeroFindsAllies*>(*pit);
+	      if (event->getHeroName() == hero_name)
+		events.push_back(*pit);
+	      break;
+	    }
+	default:
+	  break;
+	}
+    }
+  return events;
+}
 // End of file
