@@ -30,6 +30,7 @@
 
 #include "citylist.h"
 #include "ruinlist.h"
+#include "vectoredunitlist.h"
 #include "stacklist.h"
 #include "xmlhelper.h"
 #include "history.h"
@@ -309,7 +310,7 @@ void Playerlist::calculateDiplomaticRankings()
       _("Diplomat"),
       _("Pragmatist"),
       _("Politician"),
-      _("Deciever"),
+      _("Deceiver"),
       _("Scoundrel"),
       _("Turncoat"),
       _("Running Dog"),
@@ -528,6 +529,8 @@ void Playerlist::swap(Player *old_player, Player *new_player)
   clist->changeOwnership (old_player, new_player);
   Ruinlist *rlist = Ruinlist::getInstance();
   rlist->changeOwnership (old_player, new_player);
+  VectoredUnitlist *vlist = VectoredUnitlist::getInstance();
+  vlist->changeOwnership (old_player, new_player);
   if (old_player == d_activeplayer)
     {
       d_activeplayer = new_player;
@@ -809,3 +812,14 @@ void Playerlist::reorder(std::list<Uint32> order)
   d_activeplayer = getFirstLiving();
 }
 
+std::list<History *>Playerlist::getHistoryForHeroId(Uint32 id)
+{
+  std::list<History*> no_events;
+  for (iterator it = begin(); it != end(); ++it)
+    {
+      std::list<History *>events = (*it)->getHistoryForHeroId(id);
+      if (events.size() > 0)
+	return events;
+    }
+  return no_events;
+}
