@@ -27,9 +27,14 @@
 #include "ruinlist.h"
 #include "rewardlist.h"
 #include "Itemlist.h"
+#include "Item.h"
 #include "GameMap.h"
 #include "ruin.h"
 #include "ucompose.hpp"
+#include "SightMap.h"
+
+std::string Reward::d_tag = "reward";
+
 using namespace std;
 
 Reward::Reward(Type type, std::string name)
@@ -97,7 +102,7 @@ Reward_Gold::Reward_Gold (const Reward_Gold & orig)
 bool Reward_Gold::save(XML_Helper* helper)
 {
   bool retval = true;
-  retval &= helper->openTag("reward");
+  retval &= helper->openTag(Reward::d_tag);
   std::string type_str = rewardTypeToString(Reward::Type(d_type));
   retval &= helper->saveData("type", type_str);
   retval &= helper->saveData("name", d_name);
@@ -151,7 +156,7 @@ Reward_Allies::Reward_Allies (const Reward_Allies& orig)
 bool Reward_Allies::save(XML_Helper* helper)
 {
   bool retval = true;
-  retval &= helper->openTag("reward");
+  retval &= helper->openTag(Reward::d_tag);
   std::string type_str = rewardTypeToString(Reward::Type(d_type));
   retval &= helper->saveData("type", type_str);
   retval &= helper->saveData("name", d_name);
@@ -225,7 +230,7 @@ Reward_Item::Reward_Item(Item *item)
 
 bool Reward_Item::loadItem(std::string tag, XML_Helper* helper)
 {
-  if (tag == "item")
+  if (tag == Item::d_tag)
     {
       d_item = new Item(helper);
       return true;
@@ -237,7 +242,7 @@ bool Reward_Item::loadItem(std::string tag, XML_Helper* helper)
 Reward_Item::Reward_Item(XML_Helper* helper)
     :Reward(helper)
 {
-  helper->registerTag("item", sigc::mem_fun(this, &Reward_Item::loadItem));
+  helper->registerTag(Item::d_tag, sigc::mem_fun(this, &Reward_Item::loadItem));
 }
 
 Reward_Item::Reward_Item (const Reward_Item& orig)
@@ -248,7 +253,7 @@ Reward_Item::Reward_Item (const Reward_Item& orig)
 bool Reward_Item::save(XML_Helper* helper)
 {
   bool retval = true;
-  retval &= helper->openTag("reward");
+  retval &= helper->openTag(Reward::d_tag);
   std::string type_str = rewardTypeToString(Reward::Type(d_type));
   retval &= helper->saveData("type", type_str);
   retval &= helper->saveData("name", d_name);
@@ -294,7 +299,7 @@ Reward_Ruin::Reward_Ruin (const Reward_Ruin& orig)
 bool Reward_Ruin::save(XML_Helper* helper)
 {
   bool retval = true;
-  retval &= helper->openTag("reward");
+  retval &= helper->openTag(Reward::d_tag);
   std::string type_str = rewardTypeToString(Reward::Type(d_type));
   retval &= helper->saveData("type", type_str);
   retval &= helper->saveData("name", d_name);
@@ -311,9 +316,9 @@ Ruin *Reward_Ruin::getRandomHiddenRuin()
   Rewardlist *rw = Rewardlist::getInstance();
   for (Ruinlist::iterator it = rl->begin(); it != rl->end(); it++)
     {
-      if ((*it).isHidden())
-	if ((*it).getOwner() == NULL || 
-	    (*it).getOwner() == Playerlist::getInstance()->getNeutral())
+      if ((*it)->isHidden())
+	if ((*it)->getOwner() == NULL || 
+	    (*it)->getOwner() == Playerlist::getInstance()->getNeutral())
 	  {
 	    //is it already being pointed to by a reward in the rewardlist?
 	    bool found = false;
@@ -324,7 +329,7 @@ Ruin *Reward_Ruin::getRandomHiddenRuin()
 		    Ruin *r = static_cast<Reward_Ruin*>(*i)->getRuin();
 		    if (r)
 		      {
-			if (r->getPos() == (*it).getPos())
+			if (r->getPos() == (*it)->getPos())
 			  {
 			    found = true;
 			    break;
@@ -333,7 +338,7 @@ Ruin *Reward_Ruin::getRandomHiddenRuin()
 		  }
 	      }
 	    if (found == false)
-	      hidden_ruins.push_back(&*it);
+	      hidden_ruins.push_back(*it);
 	  }
     }
  if (hidden_ruins.empty())
@@ -347,19 +352,16 @@ Reward_Ruin::~Reward_Ruin()
 
 Reward_Map::Reward_Map(Vector<int> pos, std::string name, 
 		       Uint32 height, Uint32 width)
-    :Reward(Reward::MAP, name), d_height(height), d_width(width)
+    :Reward(Reward::MAP, name)
 {
-  d_loc = new LocationBox(pos);
-  d_map_name = name;
+  d_sightmap = new SightMap(name, pos, height, width);
 }
 
 bool Reward_Map::loadMap(std::string tag, XML_Helper* helper)
 {
-  if (tag == "map")
+  if (tag == SightMap::d_tag)
     {
-      d_loc = new LocationBox(helper);
-      helper->getData(d_height, "height");
-      helper->getData(d_width, "width");
+      d_sightmap = new SightMap(helper);
       return true;
     }
     
@@ -370,31 +372,23 @@ bool Reward_Map::loadMap(std::string tag, XML_Helper* helper)
 Reward_Map::Reward_Map(XML_Helper* helper)
     :Reward(helper)
 {
-  helper->registerTag("map", sigc::mem_fun(this, &Reward_Map::loadMap));
+  helper->registerTag(SightMap::d_tag, sigc::mem_fun(this, &Reward_Map::loadMap));
 }
 
 Reward_Map::Reward_Map (const Reward_Map& orig)
-	:Reward(orig), d_height(orig.d_height), d_width(orig.d_width),
-	d_map_name(orig.d_map_name)
+	:Reward(orig)
 {
-  d_loc = new LocationBox(*orig.d_loc);
+  d_sightmap = new SightMap(*orig.d_sightmap);
 }
 
-//FIXME: location has a name, and so does the reward!
 bool Reward_Map::save(XML_Helper* helper)
 {
   bool retval = true;
-  retval &= helper->openTag("reward");
+  retval &= helper->openTag(Reward::d_tag);
   std::string type_str = rewardTypeToString(Reward::Type(d_type));
   retval &= helper->saveData("type", type_str);
-  retval &= helper->saveData("name", d_name);
-  retval &= helper->openTag("map");
-  retval &= helper->saveData("x", d_loc->getPos().x);
-  retval &= helper->saveData("y", d_loc->getPos().y);
-  retval &= helper->saveData("map_name", d_map_name);
-  retval &= helper->saveData("height", d_height);
-  retval &= helper->saveData("width", d_width);
-  retval &= helper->closeTag();
+  retval &= helper->saveData("name", d_sightmap->getName());
+  retval &= d_sightmap->save(helper);
   retval &= helper->closeTag();
   return retval;
 }
@@ -411,6 +405,8 @@ void Reward_Map::getRandomMap(int *x, int *y, int *width, int *height)
 
 Reward_Map::~Reward_Map()
 {
+  if (d_sightmap)
+    delete d_sightmap;
 }
 
 std::string Reward::getDescription()
@@ -451,8 +447,8 @@ std::string Reward::getDescription()
 	{
 	  Reward_Map *m = dynamic_cast<Reward_Map *>(this);
 	  s += String::ucompose(_("Map: %1,%2 %3x%4"), 
-				  m->getLocation()->getPos().x,
-				  m->getLocation()->getPos().y,
+				  m->getLocation().x,
+				  m->getLocation().y,
 				  m->getHeight(),
 				  m->getWidth());
 	  return s;
