@@ -21,6 +21,7 @@
 #include <SDL_types.h>
 #include "vector.h"
 #include "ruinlist.h"
+#include "SightMap.h"
 #include <string>
 class Player;
 class Army;
@@ -49,6 +50,9 @@ class Reward
 {
     public:
 
+	//! The xml tag of this object in a saved-game file.
+	static std::string d_tag; 
+
 	//! The different kinds of Reward objects.
         enum Type {
 	  //! A number of gold pieces.
@@ -181,7 +185,7 @@ class Reward_Gold : public Reward
 	static Uint32 getRandomGoldPieces();
 
 	//! Save the gold reward to the opened saved-game file.
-        virtual bool save(XML_Helper* helper);
+        bool save(XML_Helper* helper);
 
 	//! Return the number of gold pieces associated with this reward.
 	Uint32 getGold() const {return d_gold;}
@@ -224,7 +228,7 @@ class Reward_Allies: public Reward
         ~Reward_Allies();
 
 	//! Save the allies reward to the opened saved-game file.
-        virtual bool save(XML_Helper* helper);
+        bool save(XML_Helper* helper);
 
 	//! Return the army prototype of the allies associated with this reward.
 	const ArmyProto * getArmy() const {return d_army;}
@@ -332,7 +336,7 @@ class Reward_Item: public Reward
 	/**
 	 * @param helper  The opened saved-game file to save the reward item to.
 	 */
-        virtual bool save(XML_Helper* helper);
+        bool save(XML_Helper* helper);
 
 	//! Get the Item object associated with this reward.
 	Item *getItem() const {return d_item;}
@@ -403,7 +407,7 @@ class Reward_Ruin: public Reward
 	 * @param helper  The opened saved-game file to write the ruin reward 
 	 *                to.
 	 */
-        virtual bool save(XML_Helper* helper);
+        bool save(XML_Helper* helper);
 
 	//! Return the Ruin object associated with this Reward_Ruin.
 	Ruin* getRuin() const 
@@ -472,13 +476,13 @@ class Reward_Map: public Reward
 	/**
 	 * @param helper  The opened saved-game file to write the ruin map to.
 	 */
-        virtual bool save(XML_Helper* helper);
+        bool save(XML_Helper* helper);
 
 	//! Get the height of the revealed portion of the game map.
-	Uint32 getHeight() const {return d_height;}
+	Uint32 getHeight() const {return d_sightmap->h;}
 
 	//! Get the width of the revealed portion of the game map.
-	Uint32 getWidth() const {return d_width;}
+	Uint32 getWidth() const {return d_sightmap->w;}
 
 	//! Return a description of a random map.
 	/**
@@ -494,27 +498,15 @@ class Reward_Map: public Reward
 	 */
 	static void getRandomMap(int *x, int *y, int *width, int *height);
 
-	LocationBox *getLocation() {return d_loc;};
+	Vector<int> getLocation() {return d_sightmap->pos;};
 
-	void setMapName(std::string name) {d_map_name = name;};
-	std::string getMapName() const {return d_map_name;};
+	SightMap * getSightMap() {return d_sightmap;};
+
+	void setMapName(std::string name) {d_sightmap->setName(name);};
+	std::string getMapName() const {return d_sightmap->getName();};
 
     private:
-	//! The height of the revealed portion of the map (in tiles).
-	/**
-	 * @note d_height + getPos().x must not exceed the height of the game
-	 *       map.
-	 */
-	Uint32 d_height;
-
-	//! The width of the revealed portion of the map (in tiles).
-	/**
-	 * @note d_width + getPos().y must not exceed the width of the game
-	 *       map.
-	 */
-	Uint32 d_width;
-	LocationBox *d_loc;
-	std::string d_map_name;
+	SightMap *d_sightmap;
 };
 
 #endif
