@@ -80,14 +80,6 @@ class Shieldsetlist : public std::list<Shieldset*>, public sigc::trackable
 	//! Return the Shieldset object that is in the given directory.
 	Shieldset *getShieldset(std::string dir) { return d_shieldsets[dir];}
 
-	//! Load the pictures for all Shieldset objects available to the game.
-	/**
-	 * Reads in the image and mask for every Shield of every Shieldset.
-	 *
-	 * @note This can only be done after SDL is initialized.
-	 */
-	void instantiatePixmaps();
-
 	SDL_Color getColor(std::string shieldset, Uint32 owner);
 	SDL_Color getMaskColor(std::string shieldset, Uint32 owner);
 
