@@ -23,7 +23,6 @@
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
 
-#include "defs.h"
 
 class Player;
 class XML_Helper;
@@ -44,6 +43,9 @@ class ShieldStyle : public sigc::trackable
 {
     public:
 
+	//! The xml tag of this object in a shieldset configuration file.
+	static std::string d_tag; 
+
 	//! The size of the shield.
 	enum Type {
 	  //! Small shields are shown on the OverviewMap object.
