@@ -18,6 +18,8 @@
 #include "signpost.h"
 #include "GameMap.h"
 
+std::string Signpost::d_tag = "signpost";
+
 Signpost::Signpost(Vector<int> pos, std::string name)
   :Location(pos), Renamable(name)
 {
@@ -45,7 +47,7 @@ bool Signpost::save(XML_Helper* helper) const
 {
     bool retval = true;
 
-    retval &= helper->openTag("signpost");
+    retval &= helper->openTag(Signpost::d_tag);
     retval &= helper->saveData("id", d_id);
     retval &= helper->saveData("x", getPos().x);
     retval &= helper->saveData("y", getPos().y);
