@@ -70,7 +70,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	 * deep copy of the stack's Army units.
 	 */
         //! Copy constructor.
-        Stack(Stack& s);
+        Stack(const Stack& s);
 
         //! Loading constructor.
         Stack(XML_Helper* helper);
@@ -153,6 +153,12 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
         //! Returns the minimum number of movement points of all Army units.
         Uint32 getGroupMoves() const;
 
+	//! Returns the maximum MP the stack would have if it were on land
+        Uint32 getMaxGroupLandMoves() const;
+
+	//! Returns the max MP the stack would have if it were in the water
+        Uint32 getMaxGroupBoatMoves() const;
+
 	//! Returns true if all Army units in the stack are grouped.
 	bool isGrouped();
 
@@ -349,6 +355,8 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	static Uint32 scout(Stack *stack, Vector<int> dest);
 
 	void payUpkeep(Player *p);
+
+	bool isMovingToOrFromAShip(Vector<int> dest, bool &on_ship) const;
     private:    
 
 
