@@ -74,6 +74,9 @@ class Temple : public NamedLocation
         //! Save the temple to the opened saved-game file.
         bool save(XML_Helper* helper) const;
 
+	bool isUnnamed() {return getName() == getDefaultName() ? true : false;};
+
+	static std::string getDefaultName() {return DEFAULT_TEMPLE_NAME;};
     protected:
 	
 	//! The type of the temple.
