@@ -16,6 +16,7 @@
 //  02110-1301, USA.
 
 #include <SDL_image.h>
+#include <algorithm>
 #include <sigc++/functors/mem_fun.h>
 
 #include "tilestyleset.h"
@@ -23,6 +24,7 @@
 #include "GraphicsCache.h"
 #include "xmlhelper.h"
 
+std::string TileStyleSet::d_tag = "tilestyleset";
 using namespace std;
 
 #include <iostream>
@@ -47,7 +49,7 @@ bool TileStyleSet::save(XML_Helper *helper)
 {
   bool retval = true;
 
-  retval &= helper->openTag("tilestyleset");
+  retval &= helper->openTag(TileStyleSet::d_tag);
   retval &= helper->saveData("name", d_name);
   for (TileStyleSet::iterator i = begin(); i != end(); ++i)
     retval &= (*i)->save(helper);
@@ -55,4 +57,17 @@ bool TileStyleSet::save(XML_Helper *helper)
 
   return retval;
 }
+
+void TileStyleSet::getUniqueTileStyleTypes(std::list<TileStyle::Type> &types)
+{
+  for (TileStyleSet::iterator i = begin(); i != end(); ++i)
+    if (find (types.begin(), types.end(), (*i)->getType()) == types.end())
+      types.push_back((*i)->getType());
+}
+
+bool TileStyleSet::validate()
+{
+  return true;
+}
+
 // End of file
