@@ -27,6 +27,9 @@
 #include "city.h"
 #include "GameMap.h"
 #include "action.h"
+#include "MapBackpack.h"
+
+std::string VectoredUnit::d_tag = "vectoredunit";
 
 VectoredUnit::VectoredUnit(Vector<int> pos, Vector<int> dest, ArmyProdBase *army, int duration, Player *player)
     :Ownable(player), LocationBox(pos), d_destination(dest), 
@@ -68,7 +71,7 @@ bool VectoredUnit::save(XML_Helper* helper) const
     bool retval = true;
     std::string name = "";
 
-    retval &= helper->openTag("vectoredunit");
+    retval &= helper->openTag(VectoredUnit::d_tag);
     retval &= helper->saveData("x", getPos().x);
     retval &= helper->saveData("y", getPos().y);
     retval &= helper->saveData("name", name);
@@ -99,20 +102,13 @@ Army *VectoredUnit::armyArrives()
       Maptile *tile = GameMap::getInstance()->getTile(d_destination);
       if (tile)
 	{
-	  std::list<Item*> items = tile->getItems();
-	  for (std::list<Item*>::iterator it = items.begin(); 
-	       it != items.end(); it++)
+	  if (tile->getBackpack()->getPlantedItem(d_owner))
 	    {
-	      if ((*it)->getPlanted() == true &&
-		  (*it)->getPlantableOwner() == d_owner)
-		{
-		  //army arrives on a planted standard
-		  Army *a = new Army(*d_army, d_owner);
-		  LocationBox loc = LocationBox(d_destination);
-		  loc.addArmy(a);
-		  return a;
-		}
-
+	      //army arrives on a planted standard
+	      Army *a = new Army(*d_army, d_owner);
+	      LocationBox loc = LocationBox(d_destination);
+	      loc.addArmy(a);
+	      return a;
 	    }
 	}
     }
